import {Service} from '@overflow/commons/api/service';
import {
    Store,
} from 'redux';

export class ServiceInvoker {
    private config: Map<string, Service>;
    private instanceMap: Map<string, Object>;
    private store: Store<any>;

    public constructor(config: Map<string, Service>, store: Store<any>) {
        this.config = config;
        this.store = store;
        this.instanceMap = new Map();

        this.initialize();
    }

    private initialize(): void {
        this.config.forEach((value, key) => {
            const instance: Service = Object.create(value);
            instance.setStore(this.store);
            this.instanceMap.set(key, instance);
        });
    }

    public invoke(className: string, methodName: string, params?: any): void {
        let classObj: Object = this.instanceMap.get(className);
        if (classObj === null || classObj === undefined) {
            console.log('Error: Cannot find the class. [' + className + ']');
            return;
        }
        if (classObj[methodName] === undefined) {
            console.log('Error: Cannot find the method. [' + methodName + ']');
            return;
        }
        classObj[methodName](params);
    }
}


export default ServiceInvoker;
